==> incidenceeditor-17.11.90.tar.xz: incidenceeditor-17.11.90/autotests/ktimezonecomboboxtest.cpp <==
/*
  Copyright 2009 Thomas McGuire <mcguire@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "ktimezonecomboboxtest.h"
#include "../src/ktimezonecombobox.h"

#include "qtest.h"

QTEST_MAIN(KTimeZoneComboBoxTest)

void KTimeZoneComboBoxTest::test_timeSpec()
{
    IncidenceEditorNG::KTimeZoneComboBox combo;
    combo.selectLocalTimeZone();
    if (combo.selectedTimeZone().id() != "UTC")
        QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());
    else
        QCOMPARE(combo.selectedTimeZone(), QTimeZone::utc());

    combo.selectTimeZone(QTimeZone());
    QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());

    combo.setFloating(true);
    QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());
}

==> incidenceeditor-20.07.80.tar.xz: incidenceeditor-20.07.80/autotests/ktimezonecomboboxtest.cpp <==
/*
  Copyright 2009 Thomas McGuire <mcguire@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include "ktimezonecomboboxtest.h"
#include "../src/ktimezonecombobox.h"

#include "qtest.h"

QTEST_MAIN(KTimeZoneComboBoxTest)

void KTimeZoneComboBoxTest::test_timeSpec()
{
    IncidenceEditorNG::KTimeZoneComboBox combo;
    combo.selectLocalTimeZone();
    if (combo.selectedTimeZone().id() != "UTC") {
        QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());
    } else {
        QCOMPARE(combo.selectedTimeZone(), QTimeZone::utc());
    }

    combo.selectTimeZone(QTimeZone());
    QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());

    combo.setFloating(true);
    QCOMPARE(combo.selectedTimeZone(), QTimeZone::systemTimeZone());
}
